@@ -1,5 +1,3 @@
-from __future__ import absolute_import, division
-
 from copy import copy
 from functools import partial
 
@@ -7,7 +5,7 @@ from .auto import tqdm as tqdm_auto
 
 try:
     import keras
-except ImportError as e:
+except (ImportError, AttributeError) as e:
     try:
         from tensorflow import keras
     except ImportError:
@@ -96,7 +94,7 @@ class TqdmCallback(keras.callbacks.Callback):
                 raise KeyError('Unknown verbosity')
 
     def on_train_end(self, *_, **__):
-        if self.verbose:
+        if hasattr(self, 'batch_bar'):
             self.batch_bar.close()
         self.epoch_bar.close()
 
